@@ -124,13 +124,13 @@ class StudentGenerator:
         df.drop(columns=["age"], inplace=True)
 
         # Create name
-        df["first_name"] = df["gender"].apply(
-            lambda x: names.get_first_name(gender=x)
+        df["firstName"] = df["gender"].apply(
+            lambda x: names.get_firstName(gender=x)
         )
-        df["last_name"] = [names.get_last_name() for x in range(self.n)]
+        df["lastName"] = [names.get_lastName() for x in range(self.n)]
 
         # Create email
-        df["email"] = df[["first_name", "last_name"]].apply(
+        df["email"] = df[["firstName", "lastName"]].apply(
             lambda x: self.generate_email(*x), axis=1
         )
 
@@ -143,14 +143,14 @@ class StudentGenerator:
         # Reorder columns
         cols = [
             "created",
-            "first_name",
-            "last_name",
+            "firstName",
+            "lastName",
             "email",
             "birthday",
             "gender",
-            "highest_degree_earned",
-            "country_iso2",
-            "admissions_quiz",
+            "highestDegreeEarned",
+            "countryISO2",
+            "admissionsQuiz",
         ]
         if self.is_experiment:
             cols.pop(-1)
