@@ -13,14 +13,17 @@ from teaching_tools.ab_test.repository import (
 class Experiment:
     """Class to generate experimental student data and insert into repository."""
 
-    def __init__(self, repo: AbstractRepository, collection: str) -> None:
-        self.attach_repository(repo)
+    def __init__(
+        self, repo: AbstractRepository, db: str, collection: str
+    ) -> None:
+        self.attach_repository(repo, db=db)
         self.collection = collection
+        self.db = db
 
     def attach_repository(
         self,
         repository: Union[AbstractRepository, MongoClient],
-        repo_name="wqu-abtest",
+        db: str,
     ) -> None:
         """Attach new repository to experiment.
 
@@ -37,7 +40,7 @@ class Experiment:
             Failed to attach repository.
         """
         if isinstance(repository, MongoClient):
-            self.repo = MongoRepository(repository, repo_name)
+            self.repo = MongoRepository(repository, db)
         elif isinstance(repository, AbstractRepository):
             self.repo = repository
         else:
